@@ -3,7 +3,7 @@ package Plack;
 use strict;
 use warnings;
 use 5.008_001;
-our $VERSION = '0.9920';
+our $VERSION = '0.9925';
 $VERSION = eval $VERSION;
 
 1;
@@ -120,8 +120,13 @@ L<Plack::Test::Suite> is a test suite to test a new PSGI server backend.
 =head2 Patches and Bug Fixes
 
 Small patches and bug fixes can be either submitted via nopaste on IRC
-L<irc://irc.perl.org/#plack> or email. You could also fork on github
-(http://github.com/miyagawa/Plack) to make larger fixes.
+L<irc://irc.perl.org/#plack> or L<the github issue
+tracker|http://github.com/miyagawa/Plack/issues>.  Forking on
+L<github|http://github.com/miyagawa/Plack> is another good way if you
+intend to make larger fixes.
+
+See also L<http://contributing.appspot.com/plack> when you think this
+document is terribly outdated.
 
 =head2 Module Namespaces
 
@@ -148,14 +153,14 @@ framework. It's like naming your application under CGI:: namespace if
 it's supposed to run on CGI and that is a really bad choice and
 confuse people.
 
-=head1 COPYRIGHT
-
-Copyright 2009- Tatsuhiko Miyagawa
-
 =head1 AUTHOR
 
 Tatsuhiko Miyagawa
 
+=head1 COPYRIGHT
+
+Copyright 2009-2010 Tatsuhiko Miyagawa
+
 =head1 CONTRIBUTORS
 
 Yuval Kogman (nothingmuch)
@@ -164,7 +169,7 @@ Tokuhiro Matsuno (tokuhirom)
 
 Kazuhiro Osawa (Yappo)
 
-Kzzuho Oku
+Kazuho Oku
 
 Florian Ragwitz (rafl)
 
